@@ -1,7 +1,9 @@
 rf.mtry.optim <- function(formula, dataset, min.mtry=NULL, max.mtry=NULL, mtry.step=1, cv.method="repeatedcv", cv.folds=10, ...) {
 
   f <- formula(formula)
+
   RNames <- attr(terms(f), "term.labels")
+
   ModelVarNo <- length(RNames)
 
   if (is.null(min.mtry)) {min.mtry <- 1}
@@ -10,9 +12,9 @@ rf.mtry.optim <- function(formula, dataset, min.mtry=NULL, max.mtry=NULL, mtry.s
   if (cv.method == "repeatedcv") {
     control <- trainControl(cv.method, repeats=5, number=cv.folds, search="grid", ...)
   } else if (cv.method == "cv") {
-    control <- trainControl(cv.method, number=cv.folds, search="grid", ...)
+    control <- trainControl(number=cv.folds, cv.method, search="grid", ...)
   } else {
-    control <- trainControl(cv.method, number=cv.folds, search="grid", ...)
+    control <- trainControl(number=cv.folds, cv.method, search="grid", ...)
   }
 
   set.seed(123)
